Module access_api

Module access_api 

Enums

AccessCreateVncticketError
struct for typed errors of method access_create_vncticket
AccessGetAccessError
struct for typed errors of method access_get_access
AccessGetPermissionsError
struct for typed errors of method access_get_permissions
AccessGetRolesError
struct for typed errors of method access_get_roles
AccessUpdatePasswordError
struct for typed errors of method access_update_password

Functions

access_create_vncticket
Verify that a VNC ticket is valid for a given Authid, path and privilege(s).
access_get_access
Directory index.
access_get_permissions
List permissions of given or currently authenticated user / API token. Optionally limited to specific path. Permissions: Requires Sys.Audit on ‘/access’, limited to own privileges otherwise.
access_get_roles
Role list
access_update_password
Change user password Each user is allowed to change his own password. Superuser can change all passwords. Permissions: Everybody is allowed to change their own password. In addition, users with ‘Permissions:Modify’ privilege may change any password on @pbs realm.