Module admin_datastore_api

Module admin_datastore_api 

Enums

AdminDatastoreCreateChangeOwnerError
struct for typed errors of method admin_datastore_create_change_owner
AdminDatastoreCreateGcError
struct for typed errors of method admin_datastore_create_gc
AdminDatastoreCreateMountError
struct for typed errors of method admin_datastore_create_mount
AdminDatastoreCreateMoveGroupError
struct for typed errors of method admin_datastore_create_move_group
AdminDatastoreCreateMoveNamespaceError
struct for typed errors of method admin_datastore_create_move_namespace
AdminDatastoreCreateNamespaceError
struct for typed errors of method admin_datastore_create_namespace
AdminDatastoreCreatePruneDatastoreError
struct for typed errors of method admin_datastore_create_prune_datastore
AdminDatastoreCreatePruneError
struct for typed errors of method admin_datastore_create_prune
AdminDatastoreCreateUnmountError
struct for typed errors of method admin_datastore_create_unmount
AdminDatastoreCreateUploadBackupLogError
struct for typed errors of method admin_datastore_create_upload_backup_log
AdminDatastoreCreateVerifyError
struct for typed errors of method admin_datastore_create_verify
AdminDatastoreDeleteGroupsError
struct for typed errors of method admin_datastore_delete_groups
AdminDatastoreDeleteNamespaceError
struct for typed errors of method admin_datastore_delete_namespace
AdminDatastoreDeleteSnapshotsError
struct for typed errors of method admin_datastore_delete_snapshots
AdminDatastoreGetActiveOperationsError
struct for typed errors of method admin_datastore_get_active_operations
AdminDatastoreGetAdminDatastoreByStoreError
struct for typed errors of method admin_datastore_get_admin_datastore_by_store
AdminDatastoreGetCatalogError
struct for typed errors of method admin_datastore_get_catalog
AdminDatastoreGetDatastoreError
struct for typed errors of method admin_datastore_get_datastore
AdminDatastoreGetDownloadDecodedError
struct for typed errors of method admin_datastore_get_download_decoded
AdminDatastoreGetDownloadError
struct for typed errors of method admin_datastore_get_download
AdminDatastoreGetFilesError
struct for typed errors of method admin_datastore_get_files
AdminDatastoreGetGcError
struct for typed errors of method admin_datastore_get_gc
AdminDatastoreGetGroupNotesError
struct for typed errors of method admin_datastore_get_group_notes
AdminDatastoreGetGroupsError
struct for typed errors of method admin_datastore_get_groups
AdminDatastoreGetNamespaceError
struct for typed errors of method admin_datastore_get_namespace
AdminDatastoreGetNotesError
struct for typed errors of method admin_datastore_get_notes
AdminDatastoreGetProtectedError
struct for typed errors of method admin_datastore_get_protected
AdminDatastoreGetPxarFileDownloadError
struct for typed errors of method admin_datastore_get_pxar_file_download
AdminDatastoreGetRrdError
struct for typed errors of method admin_datastore_get_rrd
AdminDatastoreGetSnapshotsError
struct for typed errors of method admin_datastore_get_snapshots
AdminDatastoreGetStatusError
struct for typed errors of method admin_datastore_get_status
AdminDatastoreUpdateGroupNotesError
struct for typed errors of method admin_datastore_update_group_notes
AdminDatastoreUpdateNotesError
struct for typed errors of method admin_datastore_update_notes
AdminDatastoreUpdateProtectedError
struct for typed errors of method admin_datastore_update_protected
AdminDatastoreUpdateS3RefreshError
struct for typed errors of method admin_datastore_update_s3_refresh

Functions

admin_datastore_create_change_owner
Change owner of a backup group Permissions: Datastore.Modify on whole datastore, or changing ownership between user and a user’s token for owned backups with Datastore.Backup
admin_datastore_create_gc
Start garbage collection.
admin_datastore_create_mount
Mount removable datastore.
admin_datastore_create_move_group
Move a backup group to a different namespace within the same datastore. Permissions: Requires DATASTORE_MODIFY or DATASTORE_PRUNE (+ group ownership) on the source namespace and DATASTORE_MODIFY or DATASTORE_BACKUP (+ group ownership) on the target namespace.
admin_datastore_create_move_namespace
Move a backup namespace (including all child namespaces and groups) to a new location. Permissions: Requires DATASTORE_MODIFY on the parent of ‘ns’ and on the parent of ‘target-ns’.
admin_datastore_create_namespace
Create a new datastore namespace. Permissions: Requires on /datastore/{store}[/{parent}] DATASTORE_MODIFY
admin_datastore_create_prune
Prune a group on the datastore Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_PRUNE and being the owner of the group
admin_datastore_create_prune_datastore
Prune the datastore Permissions: Requires Datastore.Modify or Datastore.Prune on the datastore/namespace.
admin_datastore_create_unmount
Unmount a removable device that is associated with the datastore
admin_datastore_create_upload_backup_log
Upload the client backup log file into a backup snapshot (‘client.log.blob’). Permissions: Only the backup creator/owner is allowed to do this.
admin_datastore_create_verify
Verify backups. This function can verify a single backup snapshot, all backups from a backup group, or all backups in the datastore. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_VERIFY for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_delete_groups
Delete backup group including all snapshots. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_PRUNE and being the owner of the group
admin_datastore_delete_namespace
Delete a backup namespace including all snapshots.
admin_datastore_delete_snapshots
Delete backup snapshot. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_PRUNE and being the owner of the group
admin_datastore_get_active_operations
Read datastore stats
admin_datastore_get_admin_datastore_by_store
Directory index.
admin_datastore_get_catalog
Get the entries of the given path of the catalog Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_datastore
Datastore list
admin_datastore_get_download
Download single raw file from backup snapshot. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_download_decoded
Download single decoded file from backup snapshot. Only works if it’s not encrypted. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_files
List snapshot files. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT or DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_gc
Garbage collection status.
admin_datastore_get_group_notes
Get "notes" for a backup group Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_groups
List backup groups. Permissions: Requires DATASTORE_AUDIT for all or DATASTORE_BACKUP for owned groups on /datastore/{store}[/{namespace}]
admin_datastore_get_namespace
List the namespaces of a datastore. Permissions: Requires DATASTORE_AUDIT, DATASTORE_MODIFY or DATASTORE_BACKUP /datastore/{store}[/{parent}]
admin_datastore_get_notes
Get "notes" for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_protected
Query protection for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_pxar_file_download
Download single file from pxar file of a backup snapshot. Only works if it’s not encrypted. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_rrd
Read datastore stats
admin_datastore_get_snapshots
List backup snapshots. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_get_status
Get datastore status. Permissions: Requires on /datastore/{store} either DATASTORE_AUDIT or DATASTORE_BACKUP for the full statistics. Counts of accessible groups are always returned, if any
admin_datastore_update_group_notes
Set "notes" for a backup group Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_update_notes
Set "notes" for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_update_protected
En- or disable protection for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_BACKUP and being the owner of the group
admin_datastore_update_s3_refresh
Refresh datastore contents from S3 to local cache store.