admin_datastore_create_verify

Function admin_datastore_create_verify 

pub async fn admin_datastore_create_verify(
    configuration: &Configuration,
    store: &str,
    admin_datastore_create_verify_request: Option<AdminDatastoreCreateVerifyRequest>,
) -> Result<AdminDatastoreCreateVerifyResponse, Error<AdminDatastoreCreateVerifyError>>
Verify backups. This function can verify a single backup snapshot, all backups from a backup group, or all backups in the datastore. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_VERIFY for any or DATASTORE_BACKUP and being the owner of the group