Module config_encryption_keys_api

Module config_encryption_keys_api 

Enums

ConfigEncryptionKeysCreateConfigEncryptionKeysByIdError
struct for typed errors of method config_encryption_keys_create_config_encryption_keys_by_id
ConfigEncryptionKeysCreateEncryptionKeysError
struct for typed errors of method config_encryption_keys_create_encryption_keys
ConfigEncryptionKeysDeleteEncryptionKeysError
struct for typed errors of method config_encryption_keys_delete_encryption_keys
ConfigEncryptionKeysGetEncryptionKeysError
struct for typed errors of method config_encryption_keys_get_encryption_keys

Functions

config_encryption_keys_create_config_encryption_keys_by_id
Toggle the archive state for the key by given id, archived keys are no longer usable to encrypt contents.
config_encryption_keys_create_encryption_keys
Create new encryption key instance or use the provided one.
config_encryption_keys_delete_encryption_keys
Remove encryption key.
config_encryption_keys_get_encryption_keys
List configured encryption keys. Permissions: List configured encryption keys filtered by Sys.Audit privileges