Module config_sync_api

Module config_sync_api 

Enums

ConfigSyncCreateSyncError
struct for typed errors of method config_sync_create_sync
ConfigSyncDeleteSyncError
struct for typed errors of method config_sync_delete_sync
ConfigSyncGetConfigSyncByIdError
struct for typed errors of method config_sync_get_config_sync_by_id
ConfigSyncGetSyncError
struct for typed errors of method config_sync_get_sync
ConfigSyncUpdateSyncError
struct for typed errors of method config_sync_update_sync

Functions

config_sync_create_sync
Create a new sync job. Permissions: For sync jobs in pull direction user needs Datastore.Backup on target datastore, and Remote.Read on source remote. Additionally, remove_vanished requires Datastore.Prune, and any owner other than the user themselves requires Datastore.Modify. For sync jobs in push direction, user needs RemoteDatastore.Backup on remote datastore, and Datastore.Audit, Datastore.Read and Datastore.Modify on the source datastore, the latter not required sync job owned by user. Additionally, remove vanished requires RemoteDatastore.Modify.
config_sync_delete_sync
Remove a sync job configuration Permissions: For sync jobs in pull direction user needs Datastore.Backup on target datastore, and Remote.Read on source remote. Additionally, remove_vanished requires Datastore.Prune, and any owner other than the user themselves requires Datastore.Modify. For sync jobs in push direction, user needs RemoteDatastore.Backup on remote datastore, and Datastore.Audit, Datastore.Read and Datastore.Modify on the source datastore, the latter not required sync job owned by user. Additionally, remove vanished requires RemoteDatastore.Modify.
config_sync_get_config_sync_by_id
Read a sync job configuration. Permissions: Limited to sync job entries where user has Datastore.Audit on target datastore, and Remote.Audit on source remote for sync jobs in pull direction. For push direction the user requires RemoteDatastore.Audit on the remote datastore and Datastore.Audit on the local datastore.
config_sync_get_sync
List all sync jobs Permissions: Limited to sync job entries where user has Datastore.Audit on target datastore, and Remote.Audit on source remote for sync jobs in pull direction. For push direction the user requires RemoteDatastore.Audit on the remote datastore and Datastore.Audit on the local datastore.
config_sync_update_sync
Update sync job config. Permissions: For sync jobs in pull direction user needs Datastore.Backup on target datastore, and Remote.Read on source remote. Additionally, remove_vanished requires Datastore.Prune, and any owner other than the user themselves requires Datastore.Modify. For sync jobs in push direction, user needs RemoteDatastore.Backup on remote datastore, and Datastore.Audit, Datastore.Read and Datastore.Modify on the source datastore, the latter not required sync job owned by user. Additionally, remove vanished requires RemoteDatastore.Modify.