config_sync_get_sync

Function config_sync_get_sync 

pub async fn config_sync_get_sync(
    configuration: &Configuration,
    sync_direction: Option<PbsSyncDirectionEnum>,
) -> Result<ConfigSyncGetSyncResponse, Error<ConfigSyncGetSyncError>>
List all sync jobs Permissions: Limited to sync job entries where user has Datastore.Audit on target datastore, and Remote.Audit on source remote for sync jobs in pull direction. For push direction the user requires RemoteDatastore.Audit on the remote datastore and Datastore.Audit on the local datastore.