config_sync_update_sync

Function config_sync_update_sync 

pub async fn config_sync_update_sync(
    configuration: &Configuration,
    id: &str,
    config_sync_update_sync_request: Option<ConfigSyncUpdateSyncRequest>,
) -> Result<ConfigSyncUpdateSyncResponse, Error<ConfigSyncUpdateSyncError>>
Update sync job config. Permissions: For sync jobs in pull direction user needs Datastore.Backup on target datastore, and Remote.Read on source remote. Additionally, remove_vanished requires Datastore.Prune, and any owner other than the user themselves requires Datastore.Modify. For sync jobs in push direction, user needs RemoteDatastore.Backup on remote datastore, and Datastore.Audit, Datastore.Read and Datastore.Modify on the source datastore, the latter not required sync job owned by user. Additionally, remove vanished requires RemoteDatastore.Modify.