Module nodes_apt_api

Module nodes_apt_api 

Enums

NodesAptCreateRepositoriesError
struct for typed errors of method nodes_apt_create_repositories
NodesAptCreateUpdateError
struct for typed errors of method nodes_apt_create_update
NodesAptGetAptError
struct for typed errors of method nodes_apt_get_apt
NodesAptGetChangelogError
struct for typed errors of method nodes_apt_get_changelog
NodesAptGetRepositoriesError
struct for typed errors of method nodes_apt_get_repositories
NodesAptGetUpdateError
struct for typed errors of method nodes_apt_get_update
NodesAptGetVersionsError
struct for typed errors of method nodes_apt_get_versions
NodesAptUpdateRepositoriesError
struct for typed errors of method nodes_apt_update_repositories

Functions

nodes_apt_create_repositories
Change the properties of the specified repository. The digest parameter asserts that the configuration has not been modified.
nodes_apt_create_update
Update the APT database
nodes_apt_get_apt
Directory index.
nodes_apt_get_changelog
Retrieve the changelog of the specified package.
nodes_apt_get_repositories
Get APT repository information.
nodes_apt_get_update
List available APT updates
nodes_apt_get_versions
Get package information for important Proxmox Backup Server packages.
nodes_apt_update_repositories
Add the repository identified by the handle. If the repository is already configured, it will be set to enabled. The digest parameter asserts that the configuration has not been modified.