Module nodes_certificates_api

Module nodes_certificates_api 

Enums

NodesCertificatesCreateCertificateError
struct for typed errors of method nodes_certificates_create_certificate
NodesCertificatesCreateCustomError
struct for typed errors of method nodes_certificates_create_custom
NodesCertificatesDeleteCustomError
struct for typed errors of method nodes_certificates_delete_custom
NodesCertificatesGetAcmeError
struct for typed errors of method nodes_certificates_get_acme
NodesCertificatesGetCertificatesError
struct for typed errors of method nodes_certificates_get_certificates
NodesCertificatesGetInfoError
struct for typed errors of method nodes_certificates_get_info
NodesCertificatesUpdateCertificateError
struct for typed errors of method nodes_certificates_update_certificate

Functions

nodes_certificates_create_certificate
Order a new ACME certificate.
nodes_certificates_create_custom
Upload a custom certificate.
nodes_certificates_delete_custom
Delete the current certificate and regenerate a self signed one.
nodes_certificates_get_acme
Directory index.
nodes_certificates_get_certificates
Directory index.
nodes_certificates_get_info
Get certificate info.
nodes_certificates_update_certificate
Renew the current ACME certificate if it is within its renewal lead time (or always if the force parameter is set).