Module nodes_tasks_api

Module nodes_tasks_api 

Enums

NodesTasksDeleteTasksError
struct for typed errors of method nodes_tasks_delete_tasks
NodesTasksGetLogError
struct for typed errors of method nodes_tasks_get_log
NodesTasksGetNodesByNodeTasksByUpidError
struct for typed errors of method nodes_tasks_get_nodes_by_node_tasks_by_upid
NodesTasksGetStatusError
struct for typed errors of method nodes_tasks_get_status
NodesTasksGetTasksError
struct for typed errors of method nodes_tasks_get_tasks

Functions

nodes_tasks_delete_tasks
Try to stop a task. Permissions: Users can stop their own tasks, or need Sys.Modify on /system/tasks.
nodes_tasks_get_log
Read the task log Permissions: Users can access their own tasks, or need Sys.Audit on /system/tasks.
nodes_tasks_get_nodes_by_node_tasks_by_upid
Directory index.
nodes_tasks_get_status
Get task status. Permissions: Users can access their own tasks, or need Sys.Audit on /system/tasks.
nodes_tasks_get_tasks
List tasks. Permissions: Users can only see their own tasks, unless they have Sys.Audit on /system/tasks.