pub struct AccessDomainsCreateSyncRequest {
pub dry_run: Option<bool>,
pub enable_new: Option<bool>,
pub remove_vanished: Option<Box<PbsRemoveVanishedField>>,
}Fields
dry_run: Option<bool>If set, do not create/delete anything
enable_new: Option<bool>Enable newly synced users immediately
remove_vanished: Option<Box<PbsRemoveVanishedField>>A semicolon-separated list of things to remove when they or the user vanishes during user synchronization. The following values are possible: entry removes the user when not returned from the sync; properties removes any properties on existing user that do not appear in the source. acl removes ACLs when the user is not returned from the sync.
Implementations