pub struct AccessTfaCreateTfaResponseData {
pub challenge: Option<String>,
pub id: Option<String>,
pub recovery: Vec<i64>,
}Fields
challenge: Option<String>When adding u2f entries, this contains a challenge the user must respond to in order to finish the registration.
id: Option<String>The id if a newly added TFA entry.
recovery: Vec<i64>A list of recovery codes as integers.
Implementations
Sourceimpl AccessTfaCreateTfaResponseData
impl AccessTfaCreateTfaResponseData
pub fn new(recovery: Vec<i64>) -> AccessTfaCreateTfaResponseData