pub struct AdminDatastoreCreatePruneRequest {
pub backup_id: String,
pub backup_type: PbsBackupTypeEnum,
pub dry_run: Option<bool>,
pub keep_daily: Option<i64>,
pub keep_hourly: Option<i64>,
pub keep_last: Option<i64>,
pub keep_monthly: Option<i64>,
pub keep_weekly: Option<i64>,
pub keep_yearly: Option<i64>,
pub ns: Option<String>,
pub use_task: Option<bool>,
}Fields
backup_id: StringBackup ID.
backup_type: PbsBackupTypeEnumBackup types.
dry_run: Option<bool>Just show what prune would do, but do not delete anything.
keep_daily: Option<i64>Number of daily backups to keep.
keep_hourly: Option<i64>Number of hourly backups to keep.
keep_last: Option<i64>Number of backups to keep.
keep_monthly: Option<i64>Number of monthly backups to keep.
keep_weekly: Option<i64>Number of weekly backups to keep.
keep_yearly: Option<i64>Number of yearly backups to keep.
ns: Option<String>Namespace.
use_task: Option<bool>Spins up an asynchronous task that does the work.
Implementations
Sourceimpl AdminDatastoreCreatePruneRequest
impl AdminDatastoreCreatePruneRequest
pub fn new( backup_id: String, backup_type: PbsBackupTypeEnum, ) -> AdminDatastoreCreatePruneRequest