pub struct AdminDatastoreCreateVerifyRequest {
pub backup_id: Option<String>,
pub backup_time: Option<i64>,
pub backup_type: Option<PbsBackupTypeEnum>,
pub ignore_verified: Option<bool>,
pub max_depth: Option<i32>,
pub ns: Option<String>,
pub outdated_after: Option<i64>,
pub read_threads: Option<i32>,
pub verify_threads: Option<i32>,
}Fields
backup_id: Option<String>Backup ID.
backup_time: Option<i64>Backup time (Unix epoch.)
backup_type: Option<PbsBackupTypeEnum>Backup types.
ignore_verified: Option<bool>Do not verify backups that are already verified if their verification is not outdated.
max_depth: Option<i32>How many levels of namespaces should be operated on (0 == no recursion)
ns: Option<String>Namespace.
outdated_after: Option<i64>Days after that a verification becomes outdated. (0 is deprecated)’
read_threads: Option<i32>The number of threads to use for reading chunks in verify job.
verify_threads: Option<i32>The number of threads to use for verifying chunks in verify job.
Implementations