AdminPruneGetPruneResponseDataInner

Struct AdminPruneGetPruneResponseDataInner 

pub struct AdminPruneGetPruneResponseDataInner {
Show 17 fields pub comment: Option<String>, pub disable: Option<bool>, pub id: String, pub keep_daily: Option<i64>, pub keep_hourly: Option<i64>, pub keep_last: Option<i64>, pub keep_monthly: Option<i64>, pub keep_weekly: Option<i64>, pub keep_yearly: Option<i64>, pub last_run_endtime: Option<i64>, pub last_run_state: Option<String>, pub last_run_upid: Option<String>, pub max_depth: Option<i32>, pub next_run: Option<i64>, pub ns: Option<String>, pub schedule: String, pub store: String,
}

Fields

comment: Option<String>

Comment.

disable: Option<bool>

Disable this job.

id: String

Job ID.

keep_daily: Option<i64>

Number of daily backups to keep.

keep_hourly: Option<i64>

Number of hourly backups to keep.

keep_last: Option<i64>

Number of backups to keep.

keep_monthly: Option<i64>

Number of monthly backups to keep.

keep_weekly: Option<i64>

Number of weekly backups to keep.

keep_yearly: Option<i64>

Number of yearly backups to keep.

last_run_endtime: Option<i64>

Endtime of the last run.

last_run_state: Option<String>

Result of the last run.

last_run_upid: Option<String>

Task UPID of the last run.

max_depth: Option<i32>

How many levels of namespaces should be operated on (0 == no recursion, empty == automatic full recursion, namespace depths reduce maximum allowed value)

next_run: Option<i64>

Estimated time of the next run (UNIX epoch).

ns: Option<String>

Namespace.

schedule: String

Run prune job at specified schedule.

store: String

Datastore name.

Implementations