pub struct AdminVerifyGetVerifyResponseDataInner {Show 14 fields
pub comment: Option<String>,
pub id: String,
pub ignore_verified: Option<bool>,
pub last_run_endtime: Option<i64>,
pub last_run_state: Option<String>,
pub last_run_upid: Option<String>,
pub max_depth: Option<i32>,
pub next_run: Option<i64>,
pub ns: Option<String>,
pub outdated_after: Option<i64>,
pub read_threads: Option<i32>,
pub schedule: Option<String>,
pub store: String,
pub verify_threads: Option<i32>,
}Fields
comment: Option<String>Comment.
id: StringJob ID.
ignore_verified: Option<bool>Do not verify backups that are already verified if their verification is not outdated.
last_run_endtime: Option<i64>Endtime of the last run.
last_run_state: Option<String>Result of the last run.
last_run_upid: Option<String>Task UPID of the last run.
max_depth: Option<i32>How many levels of namespaces should be operated on (0 == no recursion)
next_run: Option<i64>Estimated time of the next run (UNIX epoch).
ns: Option<String>Namespace.
outdated_after: Option<i64>Days after that a verification becomes outdated. (0 is deprecated)’
read_threads: Option<i32>The number of threads to use for reading chunks in verify job.
schedule: Option<String>Run verify job at specified schedule.
store: StringDatastore name.
verify_threads: Option<i32>The number of threads to use for verifying chunks in verify job.
Implementations
Sourceimpl AdminVerifyGetVerifyResponseDataInner
impl AdminVerifyGetVerifyResponseDataInner
pub fn new(id: String, store: String) -> AdminVerifyGetVerifyResponseDataInner