pub struct BackupUpgradeCreateDynamicCloseRequest {
pub chunk_count: i64,
pub csum: String,
pub size: i64,
pub wid: i32,
}Fields
chunk_count: i64Chunk count. This is used to verify that the server got all chunks.
csum: StringDigest list checksum.
size: i64File size. This is used to verify that the server got all data.
wid: i32Dynamic writer ID.
Implementations