pub struct BackupUpgradeCreateFixedCloseRequest {
pub chunk_count: i64,
pub csum: String,
pub size: i64,
pub wid: i32,
}Fields
chunk_count: i64Number of new and re-indexed chunks. Used to verify that the server got all chunk digests.
csum: StringDigest list checksum.
size: i64File size. This is used to verify that the server got all data. Ignored for incremental backups.
wid: i32Fixed writer ID.
Implementations