ConfigAccessCreateOpenidRequest

Struct ConfigAccessCreateOpenidRequest 

pub struct ConfigAccessCreateOpenidRequest {
    pub acr_values: Option<Box<PbsAcrValuesField>>,
    pub autocreate: Option<bool>,
    pub client_id: String,
    pub client_key: Option<String>,
    pub comment: Option<String>,
    pub default: Option<bool>,
    pub issuer_url: String,
    pub prompt: Option<String>,
    pub realm: String,
    pub scopes: Option<Box<PbsScopesField>>,
    pub username_claim: Option<String>,
}

Fields

acr_values: Option<Box<PbsAcrValuesField>>

OpenID ACR List

autocreate: Option<bool>

Automatically create users if they do not exist.

client_id: String

OpenID Client ID

client_key: Option<String>

OpenID Client Key

comment: Option<String>

Comment.

default: Option<bool>

True if you want this to be the default realm selected on login.

issuer_url: String

OpenID Issuer Url

prompt: Option<String>

OpenID Prompt

realm: String

Realm name.

scopes: Option<Box<PbsScopesField>>

OpenID Scope List

username_claim: Option<String>

Use the value of this attribute/claim as unique user name. It is up to the identity provider to guarantee the uniqueness. The OpenID specification only guarantees that Subject (‘sub’) is unique. Also make sure that the user is not allowed to change that attribute by himself!

Implementations