pub struct ConfigAccessGetWebauthnResponseData {
pub allow_subdomains: Option<bool>,
pub id: String,
pub origin: Option<String>,
pub rp: String,
}Fields
allow_subdomains: Option<bool>If an origin is specified, this specifies whether subdomains should be considered valid as well. May be changed at any time. Defaults to true.
id: StringRelying party ID. Must be the domain name without protocol, port or location. Changing this will break existing credentials.
origin: Option<String>Site origin. Must be a https:// URL (or http://localhost). Should contain the address users type in their browsers to access the web interface. Changing this may break existing credentials.
rp: StringRelying party name. Any text identifier. Changing this may break existing credentials.
Implementations
Sourceimpl ConfigAccessGetWebauthnResponseData
impl ConfigAccessGetWebauthnResponseData
pub fn new(id: String, rp: String) -> ConfigAccessGetWebauthnResponseData