pub struct ConfigAccessUpdateLdapRequest {Show 18 fields
pub base_dn: Option<String>,
pub bind_dn: Option<String>,
pub capath: Option<String>,
pub comment: Option<String>,
pub default: Option<bool>,
pub delete: Option<Vec<PbsDeleteEnum>>,
pub digest: Option<String>,
pub filter: Option<String>,
pub mode: Option<PbsModeEnum>,
pub password: Option<String>,
pub port: Option<i32>,
pub server1: Option<String>,
pub server2: Option<String>,
pub sync_attributes: Option<Box<PbsSyncAttributesField>>,
pub sync_defaults_options: Option<Box<PbsSyncDefaultsOptionsField>>,
pub user_attr: Option<String>,
pub user_classes: Option<Box<PbsUserClassesField>>,
pub verify: Option<bool>,
}Fields
base_dn: Option<String>LDAP Domain
bind_dn: Option<String>LDAP Domain
capath: Option<String>CA certificate to use for the server. The path can point to either a file, or a directory. If it points to a file, the PEM-formatted X.509 certificate stored at the path will be added as a trusted certificate. If the path points to a directory, the directory replaces the system’s default certificate store at /etc/ssl/certs - Every file in the directory will be loaded as a trusted certificate.
comment: Option<String>Comment.
default: Option<bool>True if you want this to be the default realm selected on login.
delete: Option<Vec<PbsDeleteEnum>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
filter: Option<String>Custom LDAP search filter for user sync
mode: Option<PbsModeEnum>LDAP connection type
password: Option<String>LDAP bind password
port: Option<i32>Port
server1: Option<String>LDAP server address
server2: Option<String>Fallback LDAP server address
sync_attributes: Option<Box<PbsSyncAttributesField>>Comma-separated list of key=value pairs for specifying which LDAP attributes map to which PBS user field. For example, to map the LDAP attribute mail to PBS’s email, write email=mail.
sync_defaults_options: Option<Box<PbsSyncDefaultsOptionsField>>sync defaults options
user_attr: Option<String>Username attribute. Used to map a userid to LDAP to an LDAP dn.
user_classes: Option<Box<PbsUserClassesField>>Comma-separated list of allowed objectClass values for user synchronization. For instance, if user-classes is set to person,user, then user synchronization will consider all LDAP entities where objectClass: person or objectClass: user.
verify: Option<bool>Verify server certificate
Implementations