pub struct ConfigAcmeUpdatePluginsRequest {
pub api: Option<String>,
pub data: Option<String>,
pub delete: Option<Vec<PbsConfigAcmeInlineEnum>>,
pub digest: Option<String>,
pub disable: Option<bool>,
pub validation_delay: Option<i32>,
}Fields
api: Option<String>DNS API Plugin Id.
data: Option<String>DNS plugin data (base64 encoded with padding).
delete: Option<Vec<PbsConfigAcmeInlineEnum>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Flag to disable the config.
validation_delay: Option<i32>Extra delay in seconds to wait before requesting validation. Allows to cope with long TTL of DNS records.
Implementations