pub struct ConfigChangerUpdateChangerRequest {
pub delete: Option<Vec<PbsConfigChangerInlineEnum>>,
pub digest: Option<String>,
pub eject_before_unload: Option<bool>,
pub export_slots: Option<Box<PbsExportSlotsField>>,
pub path: Option<String>,
}Fields
delete: Option<Vec<PbsConfigChangerInlineEnum>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
eject_before_unload: Option<bool>if set to true, tapes are ejected manually before unloading
export_slots: Option<Box<PbsExportSlotsField>>A list of slot numbers, comma separated. Those slots are reserved for Import/Export, i.e. any media in those slots are considered to be ‘offline’.
path: Option<String>Path to Linux generic SCSI device (e.g. ‘/dev/sg4’)
Implementations