pub struct ConfigNotificationsCreateSendmailRequest {
pub author: Option<String>,
pub comment: Option<String>,
pub disable: Option<bool>,
pub filter: Option<String>,
pub from_address: Option<String>,
pub mailto: Option<Vec<String>>,
pub mailto_user: Option<Vec<String>>,
pub name: String,
pub origin: Option<PbsOriginEnum>,
}Fields
Author of the mail. Defaults to ‘Proxmox Backup Server ($hostname)’
comment: Option<String>Comment.
disable: Option<bool>Disable this target.
filter: Option<String>Deprecated.
from_address: Option<String>From address for sent E-Mails. If the parameter is not set, the plugin will fall back to the email-from setting from node.cfg (PBS). If that is also not set, the plugin will default to root@$hostname, where $hostname is the hostname of the node.
mailto: Option<Vec<String>>Mail address to send a mail to.
mailto_user: Option<Vec<String>>Users to send a mail to. The email address of the user will be looked up in users.cfg.
name: StringName schema for targets and matchers
origin: Option<PbsOriginEnum>The origin of a notification configuration entry.
Implementations