pub struct ConfigNotificationsCreateSmtpRequest {Show 13 fields
pub author: Option<String>,
pub comment: Option<String>,
pub disable: Option<bool>,
pub from_address: String,
pub mailto: Option<Vec<String>>,
pub mailto_user: Option<Vec<String>>,
pub mode: Option<PbsConfigNotificationsModeEnum>,
pub name: String,
pub origin: Option<PbsOriginEnum>,
pub password: Option<String>,
pub port: Option<i32>,
pub server: String,
pub username: Option<String>,
}Fields
Author of the mail. Defaults to ‘Proxmox Backup Server ($hostname)’
comment: Option<String>Comment.
disable: Option<bool>Disable this target.
from_address: StringFrom address for the mail. SMTP relays might require that this address is owned by the user in order to avoid spoofing. The From header in the email will be set to $author <$from-address>.
mailto: Option<Vec<String>>Mail address to send a mail to.
mailto_user: Option<Vec<String>>Users to send a mail to. The email address of the user will be looked up in users.cfg.
mode: Option<PbsConfigNotificationsModeEnum>Connection security
name: StringName schema for targets and matchers
origin: Option<PbsOriginEnum>The origin of a notification configuration entry.
password: Option<String>SMTP authentication password
port: Option<i32>The port to connect to. If not set, the used port defaults to 25 (insecure), 465 (tls) or 587 (starttls), depending on the value of mode
server: StringHost name or IP of the SMTP relay.
username: Option<String>Username to use during authentication. If no username is set, no authentication will be performed. The PLAIN and LOGIN authentication methods are supported
Implementations