ConfigNotificationsGetSmtpResponseDataInner

Struct ConfigNotificationsGetSmtpResponseDataInner 

pub struct ConfigNotificationsGetSmtpResponseDataInner {
    pub author: Option<String>,
    pub comment: Option<String>,
    pub disable: Option<bool>,
    pub from_address: String,
    pub mailto: Option<Vec<String>>,
    pub mailto_user: Option<Vec<String>>,
    pub mode: Option<PbsConfigNotificationsModeEnum>,
    pub name: String,
    pub origin: Option<PbsOriginEnum>,
    pub port: Option<i32>,
    pub server: String,
    pub username: Option<String>,
}

Fields

author: Option<String>

Author of the mail. Defaults to ‘Proxmox Backup Server ($hostname)’

comment: Option<String>

Comment.

disable: Option<bool>

Disable this target.

from_address: String

From address for the mail. SMTP relays might require that this address is owned by the user in order to avoid spoofing. The From header in the email will be set to $author <$from-address>.

mailto: Option<Vec<String>>

Mail address to send a mail to.

mailto_user: Option<Vec<String>>

Users to send a mail to. The email address of the user will be looked up in users.cfg.

mode: Option<PbsConfigNotificationsModeEnum>

Connection security

name: String

Name schema for targets and matchers

origin: Option<PbsOriginEnum>

The origin of a notification configuration entry.

port: Option<i32>

The port to connect to. If not set, the used port defaults to 25 (insecure), 465 (tls) or 587 (starttls), depending on the value of mode

server: String

Host name or IP of the SMTP relay.

username: Option<String>

Username to use during authentication. If no username is set, no authentication will be performed. The PLAIN and LOGIN authentication methods are supported

Implementations