pub struct ConfigNotificationsGetWebhookResponseDataInner {
pub body: Option<String>,
pub comment: Option<String>,
pub disable: Option<bool>,
pub header: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>,
pub method: PbsMethodEnum,
pub name: String,
pub origin: Option<PbsOriginEnum>,
pub secret: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>,
pub url: String,
}Fields
body: Option<String>The HTTP body to send. Supports templating.
comment: Option<String>Comment.
disable: Option<bool>Disable this target.
header: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>Array of HTTP headers. Each entry is a property string with a name and a value. The value property contains the header in base64 encoding. Supports templating.
method: PbsMethodEnumHTTP Method to use.
name: StringName schema for targets and matchers
origin: Option<PbsOriginEnum>The origin of a notification configuration entry.
secret: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>Array of secrets. Each entry is a property string with a name and an optional value. The value property contains the secret in base64 encoding. For any API endpoints returning the endpoint config, only the secret name but not the value will be returned. When updating the config, also send all secrets that you want to keep, setting only the name but not the value. Can be accessed from templates.
url: StringHTTP(s) url with optional port.
Implementations
Sourceimpl ConfigNotificationsGetWebhookResponseDataInner
impl ConfigNotificationsGetWebhookResponseDataInner
pub fn new( method: PbsMethodEnum, name: String, url: String, ) -> ConfigNotificationsGetWebhookResponseDataInner