pub struct ConfigNotificationsUpdateMatchersRequest {
pub comment: Option<String>,
pub delete: Option<Vec<PbsConfigNotificationsInlineEnum5>>,
pub digest: Option<String>,
pub disable: Option<bool>,
pub invert_match: Option<bool>,
pub match_calendar: Option<Vec<String>>,
pub match_field: Option<Vec<String>>,
pub match_severity: Option<Vec<String>>,
pub mode: Option<PbsModeModeEnum>,
pub target: Option<Vec<String>>,
}Fields
comment: Option<String>Comment.
delete: Option<Vec<PbsConfigNotificationsInlineEnum5>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Disable this matcher.
invert_match: Option<bool>Invert match of the whole filter.
match_calendar: Option<Vec<String>>List of matched severity levels.
match_field: Option<Vec<String>>List of matched metadata fields.
match_severity: Option<Vec<String>>List of matched severity levels.
mode: Option<PbsModeModeEnum>The mode in which the results of matches are combined.
target: Option<Vec<String>>Targets to notify.
Implementations