pub struct ConfigNotificationsUpdateSendmailRequest {
pub author: Option<String>,
pub comment: Option<String>,
pub delete: Option<Vec<PbsConfigNotificationsInlineEnum2>>,
pub digest: Option<String>,
pub disable: Option<bool>,
pub from_address: Option<String>,
pub mailto: Option<Vec<String>>,
pub mailto_user: Option<Vec<String>>,
}Fields
Author of the mail. Defaults to ‘Proxmox Backup Server ($hostname)’
comment: Option<String>Comment.
delete: Option<Vec<PbsConfigNotificationsInlineEnum2>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Disable this target.
from_address: Option<String>From address for sent E-Mails. If the parameter is not set, the plugin will fall back to the email-from setting from node.cfg (PBS). If that is also not set, the plugin will default to root@$hostname, where $hostname is the hostname of the node.
mailto: Option<Vec<String>>Mail address to send a mail to.
mailto_user: Option<Vec<String>>Users to send a mail to. The email address of the user will be looked up in users.cfg.
Implementations