pub struct ConfigPruneGetPruneResponseDataInner {Show 13 fields
pub comment: Option<String>,
pub disable: Option<bool>,
pub id: String,
pub keep_daily: Option<i64>,
pub keep_hourly: Option<i64>,
pub keep_last: Option<i64>,
pub keep_monthly: Option<i64>,
pub keep_weekly: Option<i64>,
pub keep_yearly: Option<i64>,
pub max_depth: Option<i32>,
pub ns: Option<String>,
pub schedule: String,
pub store: String,
}Fields
comment: Option<String>Comment.
disable: Option<bool>Disable this job.
id: StringJob ID.
keep_daily: Option<i64>Number of daily backups to keep.
keep_hourly: Option<i64>Number of hourly backups to keep.
keep_last: Option<i64>Number of backups to keep.
keep_monthly: Option<i64>Number of monthly backups to keep.
keep_weekly: Option<i64>Number of weekly backups to keep.
keep_yearly: Option<i64>Number of yearly backups to keep.
max_depth: Option<i32>How many levels of namespaces should be operated on (0 == no recursion, empty == automatic full recursion, namespace depths reduce maximum allowed value)
ns: Option<String>Namespace.
schedule: StringRun prune job at specified schedule.
store: StringDatastore name.
Implementations