pub struct ConfigPruneUpdatePruneRequest {Show 14 fields
pub comment: Option<String>,
pub delete: Option<Vec<PbsConfigPruneInlineEnum>>,
pub digest: Option<String>,
pub disable: Option<bool>,
pub keep_daily: Option<i64>,
pub keep_hourly: Option<i64>,
pub keep_last: Option<i64>,
pub keep_monthly: Option<i64>,
pub keep_weekly: Option<i64>,
pub keep_yearly: Option<i64>,
pub max_depth: Option<i32>,
pub ns: Option<String>,
pub schedule: Option<String>,
pub store: Option<String>,
}Fields
comment: Option<String>Comment.
delete: Option<Vec<PbsConfigPruneInlineEnum>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Disable this job.
keep_daily: Option<i64>Number of daily backups to keep.
keep_hourly: Option<i64>Number of hourly backups to keep.
keep_last: Option<i64>Number of backups to keep.
keep_monthly: Option<i64>Number of monthly backups to keep.
keep_weekly: Option<i64>Number of weekly backups to keep.
keep_yearly: Option<i64>Number of yearly backups to keep.
max_depth: Option<i32>How many levels of namespaces should be operated on (0 == no recursion, empty == automatic full recursion, namespace depths reduce maximum allowed value)
ns: Option<String>Namespace.
schedule: Option<String>Run prune job at specified schedule.
store: Option<String>Datastore name.
Implementations