pub struct ConfigRemoteUpdateRemoteRequest {
pub auth_id: Option<String>,
pub comment: Option<String>,
pub delete: Option<Vec<PbsConfigRemoteInlineEnum>>,
pub digest: Option<String>,
pub fingerprint: Option<String>,
pub host: Option<String>,
pub password: Option<String>,
pub port: Option<i64>,
pub use_node_proxy: Option<bool>,
}Fields
auth_id: Option<String>Authentication ID
comment: Option<String>Comment.
delete: Option<Vec<PbsConfigRemoteInlineEnum>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
fingerprint: Option<String>X509 certificate fingerprint (sha256).
host: Option<String>DNS name or IP address.
password: Option<String>Password or auth token for remote host.
port: Option<i64>The (optional) port
use_node_proxy: Option<bool>Use the http proxy configuration of the node for remote connections.
Implementations