pub struct ConfigSyncGetSyncResponseDataInner {Show 26 fields
pub active_encryption_key: Option<String>,
pub associated_key: Option<Vec<String>>,
pub burst_in: Option<String>,
pub burst_out: Option<String>,
pub comment: Option<String>,
pub encrypted_only: Option<bool>,
pub group_filter: Option<Vec<String>>,
pub id: String,
pub max_depth: Option<i32>,
pub ns: Option<String>,
pub owner: Option<String>,
pub rate_in: Option<String>,
pub rate_out: Option<String>,
pub remote: Option<String>,
pub remote_ns: Option<String>,
pub remote_store: String,
pub remove_vanished: Option<bool>,
pub resync_corrupt: Option<bool>,
pub run_on_mount: Option<bool>,
pub schedule: Option<String>,
pub store: String,
pub sync_direction: Option<PbsAdminSyncSyncDirectionEnum>,
pub transfer_last: Option<i64>,
pub unmount_on_done: Option<bool>,
pub verified_only: Option<bool>,
pub worker_threads: Option<i32>,
}Fields
active_encryption_key: Option<String>ID to uniquely identify encryption/decription key
associated_key: Option<Vec<String>>List of cryptographic keys associated with sync job.
burst_in: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
burst_out: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
comment: Option<String>Comment.
encrypted_only: Option<bool>Only synchronize encrypted backup snapshots, exclude others.
group_filter: Option<Vec<String>>List of group filters.
id: StringJob ID.
max_depth: Option<i32>How many levels of namespaces should be operated on (0 == no recursion, empty == automatic full recursion, namespace depths reduce maximum allowed value)
ns: Option<String>Namespace.
owner: Option<String>Authentication ID
rate_in: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
rate_out: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
remote: Option<String>Remote ID.
remote_ns: Option<String>Namespace.
remote_store: StringDatastore name.
remove_vanished: Option<bool>Delete vanished backups. This remove the local copy if the remote backup was deleted.
resync_corrupt: Option<bool>If the verification failed for a local snapshot, try to pull it again.
run_on_mount: Option<bool>Run this job when a relevant datastore is mounted.
schedule: Option<String>Run sync job at specified schedule.
store: StringDatastore name.
sync_direction: Option<PbsAdminSyncSyncDirectionEnum>Direction of the sync job, push or pull
transfer_last: Option<i64>Limit transfer to last N snapshots (per group), skipping others
unmount_on_done: Option<bool>Unmount involved removable datastore after the sync job finishes. Requires ‘run-on-mount’ to be enabled.
verified_only: Option<bool>Only synchronize verified backup snapshots, exclude others.
worker_threads: Option<i32>The number of worker threads to process groups in parallel.
Implementations