pub struct NodesAptCreateUpdateRequest {
pub notify: Option<bool>,
pub quiet: Option<bool>,
}Fields
notify: Option<bool>Send notification mail about new package updates available to the email address configured for ‘root@pam’).
quiet: Option<bool>Only produces output suitable for logging, omitting progress indicators.
Implementations
Sourceimpl NodesAptCreateUpdateRequest
impl NodesAptCreateUpdateRequest
pub fn new() -> NodesAptCreateUpdateRequest