pub struct NodesConfigGetConfigResponseData {Show 14 fields
pub acme: Option<Box<PbsAcmeField>>,
pub acmedomain0: Option<Box<PbsAcmedomainField>>,
pub acmedomain1: Option<Box<PbsAcmedomainField>>,
pub acmedomain2: Option<Box<PbsAcmedomainField>>,
pub acmedomain3: Option<Box<PbsAcmedomainField>>,
pub acmedomain4: Option<Box<PbsAcmedomainField>>,
pub ciphers_tls_1_2: Option<String>,
pub ciphers_tls_1_3: Option<String>,
pub consent_text: Option<String>,
pub default_lang: Option<PbsDefaultLangEnum>,
pub description: Option<String>,
pub email_from: Option<String>,
pub http_proxy: Option<String>,
pub task_log_max_days: Option<i64>,
}Fields
acme: Option<Box<PbsAcmeField>>The acme account to use on this node.
acmedomain0: Option<Box<PbsAcmedomainField>>ACME domain configuration string
acmedomain1: Option<Box<PbsAcmedomainField>>ACME domain configuration string
acmedomain2: Option<Box<PbsAcmedomainField>>ACME domain configuration string
acmedomain3: Option<Box<PbsAcmedomainField>>ACME domain configuration string
acmedomain4: Option<Box<PbsAcmedomainField>>ACME domain configuration string
ciphers_tls_1_2: Option<String>OpenSSL cipher list used by the proxy for TLS <= 1.2
ciphers_tls_1_3: Option<String>OpenSSL ciphersuites list used by the proxy for TLS 1.3
consent_text: Option<String>Consent banner text
default_lang: Option<PbsDefaultLangEnum>All available languages in Proxmox. Taken from proxmox-i18n repository. pt_BR, zh_CN, and zh_TW use the same case in the translation files.
description: Option<String>Comment (multiple lines).
email_from: Option<String>E-Mail Address.
http_proxy: Option<String>HTTP proxy configuration [http://]
task_log_max_days: Option<i64>Maximum days to keep Task logs
Implementations