pub struct PullCreatePullRequest {Show 18 fields
pub burst_in: Option<String>,
pub burst_out: Option<String>,
pub decryption_keys: Option<Vec<String>>,
pub encrypted_only: Option<bool>,
pub group_filter: Option<Vec<String>>,
pub max_depth: Option<i32>,
pub ns: Option<String>,
pub rate_in: Option<String>,
pub rate_out: Option<String>,
pub remote: Option<String>,
pub remote_ns: Option<String>,
pub remote_store: String,
pub remove_vanished: Option<bool>,
pub resync_corrupt: Option<bool>,
pub store: String,
pub transfer_last: Option<i64>,
pub verified_only: Option<bool>,
pub worker_threads: Option<i32>,
}Fields
burst_in: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
burst_out: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
decryption_keys: Option<Vec<String>>List of decryption keys.
encrypted_only: Option<bool>Only synchronize encrypted backup snapshots, exclude others.
group_filter: Option<Vec<String>>List of group filters.
max_depth: Option<i32>How many levels of namespaces should be operated on (0 == no recursion, empty == automatic full recursion, namespace depths reduce maximum allowed value)
ns: Option<String>Namespace.
rate_in: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
rate_out: Option<String>Byte size with optional unit (B, KB (base 10), MB, GB, …, KiB (base 2), MiB, Gib, …).
remote: Option<String>Remote ID.
remote_ns: Option<String>Namespace.
remote_store: StringDatastore name.
remove_vanished: Option<bool>Delete vanished backups. This remove the local copy if the remote backup was deleted.
resync_corrupt: Option<bool>If the verification failed for a local snapshot, try to pull it again.
store: StringDatastore name.
transfer_last: Option<i64>Limit transfer to last N snapshots (per group), skipping others
verified_only: Option<bool>Only synchronize verified backup snapshots, exclude others.
worker_threads: Option<i32>The number of worker threads to process groups in parallel.
Implementations
Sourceimpl PullCreatePullRequest
impl PullCreatePullRequest
pub fn new(remote_store: String, store: String) -> PullCreatePullRequest