pub struct TapeBackupCreateBackupRequest {Show 13 fields
pub drive: String,
pub eject_media: Option<bool>,
pub export_media_set: Option<bool>,
pub force_media_set: Option<bool>,
pub group_filter: Option<Vec<String>>,
pub latest_only: Option<bool>,
pub max_depth: Option<i32>,
pub notification_mode: Option<PbsNotificationModeEnum>,
pub notify_user: Option<String>,
pub ns: Option<String>,
pub pool: String,
pub store: String,
pub worker_threads: Option<i32>,
}Fields
drive: StringDrive Identifier.
eject_media: Option<bool>Eject media upon job completion.
export_media_set: Option<bool>Export media set upon job completion.
force_media_set: Option<bool>Ignore the allocation policy and start a new media-set.
group_filter: Option<Vec<String>>List of group filters.
latest_only: Option<bool>Backup latest snapshots only.
max_depth: Option<i32>How many levels of namespaces should be operated on (0 == no recursion)
notification_mode: Option<PbsNotificationModeEnum>Configure how notifications for this datastore should be sent. legacy-sendmail sends email notifications to the user configured in notify-user via the system’s sendmail executable. notification-system emits matchable notification events to the notification system.
notify_user: Option<String>User ID
ns: Option<String>Namespace.
pool: StringMedia pool name.
store: StringDatastore name.
worker_threads: Option<i32>The number of threads to use for the tape backup job.
Implementations