TapeCreateRestoreRequest

Struct TapeCreateRestoreRequest 

pub struct TapeCreateRestoreRequest {
    pub drive: String,
    pub media_set: String,
    pub namespaces: Option<Vec<TapeCreateRestoreRequestNamespacesInner>>,
    pub notification_mode: Option<PbsNotificationModeEnum>,
    pub notify_user: Option<String>,
    pub owner: Option<String>,
    pub snapshots: Option<Vec<String>>,
    pub store: Box<PbsStoreField>,
}

Fields

drive: String

Drive Identifier.

media_set: String

Media set UUID.

namespaces: Option<Vec<TapeCreateRestoreRequestNamespacesInner>>

List of namespace to restore.

notification_mode: Option<PbsNotificationModeEnum>

Configure how notifications for this datastore should be sent. legacy-sendmail sends email notifications to the user configured in notify-user via the system’s sendmail executable. notification-system emits matchable notification events to the notification system.

notify_user: Option<String>

User ID

owner: Option<String>

Authentication ID

snapshots: Option<Vec<String>>

List of snapshots.

store: Box<PbsStoreField>

A list of Datastore mappings (or single datastore), comma separated. For example ‘a=b,e’ maps the source datastore ‘a’ to target ’b and all other sources to the default ‘e’. If no default is given, only the specified sources are mapped.

Implementations