pub struct TapeDriveGetStatusResponseData {Show 18 fields
pub alert_flags: Option<String>,
pub block_number: Option<i64>,
pub blocksize: i32,
pub buffer_mode: i32,
pub bytes_read: Option<i64>,
pub bytes_written: Option<i64>,
pub compression: bool,
pub density: Option<PbsTapeDriveDensityEnum>,
pub drive_activity: Option<PbsActivityEnum>,
pub file_number: Option<i64>,
pub manufactured: Option<i64>,
pub medium_passes: Option<i64>,
pub medium_wearout: Option<f64>,
pub product: String,
pub revision: String,
pub vendor: String,
pub volume_mounts: Option<i64>,
pub write_protect: Option<bool>,
}Fields
alert_flags: Option<String>Tape Alert Flags
block_number: Option<i64>Current block number
blocksize: i32Block size (0 is variable size)
buffer_mode: i32Drive buffer mode
bytes_read: Option<i64>Total Bytes Read in Medium Life
bytes_written: Option<i64>Total Bytes Written in Medium Life
compression: boolCompression enabled
density: Option<PbsTapeDriveDensityEnum>The density of a tape medium, derived from the LTO version.
drive_activity: Option<PbsActivityEnum>The DT Device Activity from DT Device Status LP page
file_number: Option<i64>Current file number
manufactured: Option<i64>Medium Manufacture Date (epoch)
medium_passes: Option<i64>Count of the total number of times the medium has passed over the head.
medium_wearout: Option<f64>Estimated tape wearout factor (assuming max. 16000 end-to-end passes)
product: StringProduct
revision: StringRevision
vendor: StringVendor
volume_mounts: Option<i64>Number of mounts for the current volume (i.e., Thread Count)
write_protect: Option<bool>Media is write protected
Implementations