Enums
- Access
Create Vncticket Error - struct for typed errors of method
access_create_vncticket - Access
GetAccess Error - struct for typed errors of method
access_get_access - Access
GetPermissions Error - struct for typed errors of method
access_get_permissions - Access
GetRoles Error - struct for typed errors of method
access_get_roles - Access
Update Password Error - struct for typed errors of method
access_update_password
Functions
- access_
create_ vncticket - Verify that a VNC ticket is valid for a given Authid, path and privilege(s).
- access_
get_ access - Directory index.
- access_
get_ permissions - List permissions of given or currently authenticated user / API token. Optionally limited to specific path. Permissions: Requires Sys.Audit on ‘/access’, limited to own privileges otherwise.
- access_
get_ roles - Role list
- access_
update_ password - Change user password Each user is allowed to change his own password. Superuser can change all passwords. Permissions: Everybody is allowed to change their own password. In addition, users with ‘Permissions:Modify’ privilege may change any password on @pbs realm.