Enums
- Admin
Datastore Create Change Owner Error - struct for typed errors of method
admin_datastore_create_change_owner - Admin
Datastore Create GcError - struct for typed errors of method
admin_datastore_create_gc - Admin
Datastore Create Mount Error - struct for typed errors of method
admin_datastore_create_mount - Admin
Datastore Create Move Group Error - struct for typed errors of method
admin_datastore_create_move_group - Admin
Datastore Create Move Namespace Error - struct for typed errors of method
admin_datastore_create_move_namespace - Admin
Datastore Create Namespace Error - struct for typed errors of method
admin_datastore_create_namespace - Admin
Datastore Create Prune Datastore Error - struct for typed errors of method
admin_datastore_create_prune_datastore - Admin
Datastore Create Prune Error - struct for typed errors of method
admin_datastore_create_prune - Admin
Datastore Create Unmount Error - struct for typed errors of method
admin_datastore_create_unmount - Admin
Datastore Create Upload Backup LogError - struct for typed errors of method
admin_datastore_create_upload_backup_log - Admin
Datastore Create Verify Error - struct for typed errors of method
admin_datastore_create_verify - Admin
Datastore Delete Groups Error - struct for typed errors of method
admin_datastore_delete_groups - Admin
Datastore Delete Namespace Error - struct for typed errors of method
admin_datastore_delete_namespace - Admin
Datastore Delete Snapshots Error - struct for typed errors of method
admin_datastore_delete_snapshots - Admin
Datastore GetActive Operations Error - struct for typed errors of method
admin_datastore_get_active_operations - Admin
Datastore GetAdmin Datastore ByStore Error - struct for typed errors of method
admin_datastore_get_admin_datastore_by_store - Admin
Datastore GetCatalog Error - struct for typed errors of method
admin_datastore_get_catalog - Admin
Datastore GetDatastore Error - struct for typed errors of method
admin_datastore_get_datastore - Admin
Datastore GetDownload Decoded Error - struct for typed errors of method
admin_datastore_get_download_decoded - Admin
Datastore GetDownload Error - struct for typed errors of method
admin_datastore_get_download - Admin
Datastore GetFiles Error - struct for typed errors of method
admin_datastore_get_files - Admin
Datastore GetGc Error - struct for typed errors of method
admin_datastore_get_gc - Admin
Datastore GetGroup Notes Error - struct for typed errors of method
admin_datastore_get_group_notes - Admin
Datastore GetGroups Error - struct for typed errors of method
admin_datastore_get_groups - Admin
Datastore GetNamespace Error - struct for typed errors of method
admin_datastore_get_namespace - Admin
Datastore GetNotes Error - struct for typed errors of method
admin_datastore_get_notes - Admin
Datastore GetProtected Error - struct for typed errors of method
admin_datastore_get_protected - Admin
Datastore GetPxar File Download Error - struct for typed errors of method
admin_datastore_get_pxar_file_download - Admin
Datastore GetRrd Error - struct for typed errors of method
admin_datastore_get_rrd - Admin
Datastore GetSnapshots Error - struct for typed errors of method
admin_datastore_get_snapshots - Admin
Datastore GetStatus Error - struct for typed errors of method
admin_datastore_get_status - Admin
Datastore Update Group Notes Error - struct for typed errors of method
admin_datastore_update_group_notes - Admin
Datastore Update Notes Error - struct for typed errors of method
admin_datastore_update_notes - Admin
Datastore Update Protected Error - struct for typed errors of method
admin_datastore_update_protected - Admin
Datastore Update S3Refresh Error - struct for typed errors of method
admin_datastore_update_s3_refresh
Functions
- admin_
datastore_ create_ change_ owner - Change owner of a backup group Permissions: Datastore.Modify on whole datastore, or changing ownership between user and a user’s token for owned backups with Datastore.Backup
- admin_
datastore_ create_ gc - Start garbage collection.
- admin_
datastore_ create_ mount - Mount removable datastore.
- admin_
datastore_ create_ move_ group - Move a backup group to a different namespace within the same datastore. Permissions: Requires DATASTORE_MODIFY or DATASTORE_PRUNE (+ group ownership) on the source namespace and DATASTORE_MODIFY or DATASTORE_BACKUP (+ group ownership) on the target namespace.
- admin_
datastore_ create_ move_ namespace - Move a backup namespace (including all child namespaces and groups) to a new location. Permissions: Requires DATASTORE_MODIFY on the parent of ‘ns’ and on the parent of ‘target-ns’.
- admin_
datastore_ create_ namespace - Create a new datastore namespace. Permissions: Requires on /datastore/{store}[/{parent}] DATASTORE_MODIFY
- admin_
datastore_ create_ prune - Prune a group on the datastore Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_PRUNE and being the owner of the group
- admin_
datastore_ create_ prune_ datastore - Prune the datastore Permissions: Requires Datastore.Modify or Datastore.Prune on the datastore/namespace.
- admin_
datastore_ create_ unmount - Unmount a removable device that is associated with the datastore
- admin_
datastore_ create_ upload_ backup_ log - Upload the client backup log file into a backup snapshot (‘client.log.blob’). Permissions: Only the backup creator/owner is allowed to do this.
- admin_
datastore_ create_ verify - Verify backups. This function can verify a single backup snapshot, all backups from a backup group, or all backups in the datastore. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_VERIFY for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ delete_ groups - Delete backup group including all snapshots. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_PRUNE and being the owner of the group
- admin_
datastore_ delete_ namespace - Delete a backup namespace including all snapshots.
- admin_
datastore_ delete_ snapshots - Delete backup snapshot. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_PRUNE and being the owner of the group
- admin_
datastore_ get_ active_ operations - Read datastore stats
- admin_
datastore_ get_ admin_ datastore_ by_ store - Directory index.
- admin_
datastore_ get_ catalog - Get the entries of the given path of the catalog Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ datastore - Datastore list
- admin_
datastore_ get_ download - Download single raw file from backup snapshot. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ download_ decoded - Download single decoded file from backup snapshot. Only works if it’s not encrypted. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ files - List snapshot files. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT or DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ gc - Garbage collection status.
- admin_
datastore_ get_ group_ notes - Get "notes" for a backup group Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ groups - List backup groups. Permissions: Requires DATASTORE_AUDIT for all or DATASTORE_BACKUP for owned groups on /datastore/{store}[/{namespace}]
- admin_
datastore_ get_ namespace - List the namespaces of a datastore. Permissions: Requires DATASTORE_AUDIT, DATASTORE_MODIFY or DATASTORE_BACKUP /datastore/{store}[/{parent}]
- admin_
datastore_ get_ notes - Get "notes" for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ protected - Query protection for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ pxar_ file_ download - Download single file from pxar file of a backup snapshot. Only works if it’s not encrypted. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_READ for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ rrd - Read datastore stats
- admin_
datastore_ get_ snapshots - List backup snapshots. Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_AUDIT for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ get_ status - Get datastore status. Permissions: Requires on /datastore/{store} either DATASTORE_AUDIT or DATASTORE_BACKUP for the full statistics. Counts of accessible groups are always returned, if any
- admin_
datastore_ update_ group_ notes - Set "notes" for a backup group Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ update_ notes - Set "notes" for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ update_ protected - En- or disable protection for a specific backup Permissions: Requires on /datastore/{store}[/{namespace}] either DATASTORE_MODIFY for any or DATASTORE_BACKUP and being the owner of the group
- admin_
datastore_ update_ s3_ refresh - Refresh datastore contents from S3 to local cache store.