Enums
- Nodes
Certificates Create Certificate Error - struct for typed errors of method
nodes_certificates_create_certificate - Nodes
Certificates Create Custom Error - struct for typed errors of method
nodes_certificates_create_custom - Nodes
Certificates Delete Custom Error - struct for typed errors of method
nodes_certificates_delete_custom - Nodes
Certificates GetAcme Error - struct for typed errors of method
nodes_certificates_get_acme - Nodes
Certificates GetCertificates Error - struct for typed errors of method
nodes_certificates_get_certificates - Nodes
Certificates GetInfo Error - struct for typed errors of method
nodes_certificates_get_info - Nodes
Certificates Update Certificate Error - struct for typed errors of method
nodes_certificates_update_certificate
Functions
- nodes_
certificates_ create_ certificate - Order a new ACME certificate.
- nodes_
certificates_ create_ custom - Upload a custom certificate.
- nodes_
certificates_ delete_ custom - Delete the current certificate and regenerate a self signed one.
- nodes_
certificates_ get_ acme - Directory index.
- nodes_
certificates_ get_ certificates - Directory index.
- nodes_
certificates_ get_ info - Get certificate info.
- nodes_
certificates_ update_ certificate - Renew the current ACME certificate if it is within its renewal lead time (or always if the
forceparameter is set).