Enums
- Nodes
Tasks Delete Tasks Error - struct for typed errors of method
nodes_tasks_delete_tasks - Nodes
Tasks GetLog Error - struct for typed errors of method
nodes_tasks_get_log - Nodes
Tasks GetNodes ByNode Tasks ByUpid Error - struct for typed errors of method
nodes_tasks_get_nodes_by_node_tasks_by_upid - Nodes
Tasks GetStatus Error - struct for typed errors of method
nodes_tasks_get_status - Nodes
Tasks GetTasks Error - struct for typed errors of method
nodes_tasks_get_tasks
Functions
- nodes_
tasks_ delete_ tasks - Try to stop a task. Permissions: Users can stop their own tasks, or need Sys.Modify on /system/tasks.
- nodes_
tasks_ get_ log - Read the task log Permissions: Users can access their own tasks, or need Sys.Audit on /system/tasks.
- nodes_
tasks_ get_ nodes_ by_ node_ tasks_ by_ upid - Directory index.
- nodes_
tasks_ get_ status - Get task status. Permissions: Users can access their own tasks, or need Sys.Audit on /system/tasks.
- nodes_
tasks_ get_ tasks - List tasks. Permissions: Users can only see their own tasks, unless they have Sys.Audit on /system/tasks.