pub struct ConfigNotificationsUpdateWebhookRequest {
pub body: Option<String>,
pub comment: Option<String>,
pub delete: Option<Vec<PbsConfigNotificationsInlineEnum4>>,
pub digest: Option<String>,
pub disable: Option<bool>,
pub header: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>,
pub method: Option<PbsMethodEnum>,
pub secret: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>,
pub url: Option<String>,
}Fields
body: Option<String>The HTTP body to send. Supports templating.
comment: Option<String>Comment.
delete: Option<Vec<PbsConfigNotificationsInlineEnum4>>List of properties to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA256 digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Disable this target.
header: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>Array of HTTP headers. Each entry is a property string with a name and a value. The value property contains the header in base64 encoding. Supports templating.
method: Option<PbsMethodEnum>HTTP Method to use.
secret: Option<Vec<ConfigNotificationsGetWebhookResponseDataInnerHeaderInner>>Array of secrets. Each entry is a property string with a name and an optional value. The value property contains the secret in base64 encoding. For any API endpoints returning the endpoint config, only the secret name but not the value will be returned. When updating the config, also send all secrets that you want to keep, setting only the name but not the value. Can be accessed from templates.
url: Option<String>HTTP(s) url with optional port.
Implementations